==> eiffelstudio-18.07.10.1981.tar: F_code/C66/li3288.c <==
/*
 * Code for class LIST [INTEGER_64]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "li3288.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {LIST}.is_equal */
EIF_BOOLEAN F1436_14245 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_64 ti8_1;
	EIF_INTEGER_64 ti8_2;
	EIF_INTEGER_64 ti8_3;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	if ((EIF_BOOLEAN)(Current == arg1)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		Result = '\0';
		tb1 = '\0';
		{
			/* INLINED CODE (is_empty) */
			tb2 = (EIF_BOOLEAN)  0;
			ti4_1 = F1494_14571(Current);
			tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
			/* END INLINED CODE */
		}
		{
			/* INLINED CODE (is_empty) */
			tb3 = (EIF_BOOLEAN)  0;
			ti4_1 = F1494_14571(RTCW(arg1));
			tb3 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
			/* END INLINED CODE */
		}
		tb3 = tb3;
		if ((EIF_BOOLEAN)(tb2 == tb3)) {
			tb2 = *(EIF_BOOLEAN *)(RTCW(arg1) + O7264[Dtype(arg1)-569]);
			tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current + O7264[dtype-569]) == tb2);
		}
		if (tb1) {
			{
				/* INLINED CODE (count) */
				ti4_1 = (EIF_INTEGER_32)  0;
				tr1 = *(EIF_REFERENCE *)(Current);
				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
				/* END INLINED CODE */
			}
			{
				/* INLINED CODE (count) */
				ti4_2 = (EIF_INTEGER_32)  0;
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
				/* END INLINED CODE */
			}
			ti4_2 = ti4_2;
			Result = (EIF_BOOLEAN)(ti4_1 == ti4_2);
		}
		tb1 = '\0';
		if (Result) {
			{
				/* INLINED CODE (is_empty) */
				tb2 = (EIF_BOOLEAN)  0;
				ti4_1 = F1494_14571(Current);
				tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
				/* END INLINED CODE */
			}
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			tb1 = '\0';
			tr1 = F1494_14561(Current);
			loc1 = tr1;
			if (EIF_TEST(loc1)) {
				tr1 = F1494_14561(RTCW(arg1));
				loc2 = tr1;
				tb1 = EIF_TEST(loc2);
			}
			if (tb1) {
				(FUNCTION_CAST(void, (EIF_REFERENCE)) R7372[dtype-657])(Current);
				(FUNCTION_CAST(void, (EIF_REFERENCE)) R7372[Dtype(arg1)-657])(RTCW(arg1));
				for (;;) {
					tb1 = '\01';
					{
						/* INLINED CODE (after) */
						tb2 = (EIF_BOOLEAN)  0;
						ti4_1 = F1494_14560(Current);
						ti4_2 = F1494_14571(Current);
						tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_2 + ((EIF_INTEGER_32) 1L)));
						/* END INLINED CODE */
					}
					if (!tb2) {
						tb1 = (EIF_BOOLEAN) !Result;
					}
					if (tb1) break;
					if (*(EIF_BOOLEAN *)(Current + O7264[dtype-569])) {
						{
							/* INLINED CODE (item) */
							ti8_1 = (EIF_INTEGER_64)  0;
							tr1 = *(EIF_REFERENCE *)(Current);
							ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
							ti8_1 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_INTEGER_64 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						ti8_2 = ti8_1;
						{
							/* INLINED CODE (item) */
							ti8_3 = (EIF_INTEGER_64)  0;
							tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
							ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
							ti8_3 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_INTEGER_64 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						ti8_3 = ti8_3;
						Result = (EIF_BOOLEAN) (ti8_2 == ti8_3);
					} else {
						{
							/* INLINED CODE (item) */
							ti8_1 = (EIF_INTEGER_64)  0;
							tr1 = *(EIF_REFERENCE *)(Current);
							ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
							ti8_1 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_INTEGER_64 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						ti8_2 = ti8_1;
						{
							/* INLINED CODE (item) */
							ti8_3 = (EIF_INTEGER_64)  0;
							tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
							ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
							ti8_3 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_INTEGER_64 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						ti8_3 = ti8_3;
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti8_2 == ti8_3);
					}
					{
						/* INLINED CODE (forth) */
						(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))++;
						/* END INLINED CODE */
					}
					;
					{
						/* INLINED CODE (forth) */
						(*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_))++;
						/* END INLINED CODE */
					}
					;
				}
				F1494_14586(Current, loc1);
				F1494_14586(RTCW(arg1), loc2);
			} else {
			}
		} else {
			tb2 = '\0';
			tb3 = '\0';
			{
				/* INLINED CODE (is_empty) */
				tb4 = (EIF_BOOLEAN)  0;
				ti4_1 = F1494_14571(Current);
				tb4 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
				/* END INLINED CODE */
			}
			if (tb4) {
				{
					/* INLINED CODE (is_empty) */
					tb4 = (EIF_BOOLEAN)  0;
					ti4_1 = F1494_14571(RTCW(arg1));
					tb4 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
					/* END INLINED CODE */
				}
				tb4 = tb4;
				tb3 = tb4;
			}
			if (tb3) {
				tb3 = *(EIF_BOOLEAN *)(RTCW(arg1) + O7264[Dtype(arg1)-569]);
				tb2 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current + O7264[dtype-569]) == tb3);
			}
			if (tb2) {
				RTLE;
				return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		}
	}
	RTLE;
	return Result;
}

/* {LIST}.after */
EIF_BOOLEAN F1436_14246 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
	{
		/* INLINED CODE (count) */
		ti4_2 = (EIF_INTEGER_32)  0;
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_3 + ((EIF_INTEGER_32) 1L)));
	RTLE;
	return Result;
}

/* {LIST}.before */
EIF_BOOLEAN F1436_14247 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) == ((EIF_INTEGER_32) 0L));
}

void EIF_Minit3288 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C66/li3288.c <==
/*
 * Code for class LIST [NATURAL_8]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "li3288.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {LIST}.is_equal */
EIF_BOOLEAN F1450_14547 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_NATURAL_8 tu1_1;
	EIF_NATURAL_8 tu1_2;
	EIF_NATURAL_8 tu1_3;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	if ((EIF_BOOLEAN)(Current == arg1)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		Result = '\0';
		tb1 = '\0';
		{
			/* INLINED CODE (is_empty) */
			tb2 = (EIF_BOOLEAN)  0;
			ti4_1 = F1509_14880(Current);
			tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
			/* END INLINED CODE */
		}
		{
			/* INLINED CODE (is_empty) */
			tb3 = (EIF_BOOLEAN)  0;
			ti4_1 = F1509_14880(RTCW(arg1));
			tb3 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
			/* END INLINED CODE */
		}
		tb3 = tb3;
		if ((EIF_BOOLEAN)(tb2 == tb3)) {
			tb2 = *(EIF_BOOLEAN *)(RTCW(arg1) + O11691[Dtype(arg1)-1103]);
			tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current + O11691[dtype-1103]) == tb2);
		}
		if (tb1) {
			{
				/* INLINED CODE (count) */
				ti4_1 = (EIF_INTEGER_32)  0;
				tr1 = *(EIF_REFERENCE *)(Current);
				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
				/* END INLINED CODE */
			}
			{
				/* INLINED CODE (count) */
				ti4_2 = (EIF_INTEGER_32)  0;
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
				/* END INLINED CODE */
			}
			ti4_2 = ti4_2;
			Result = (EIF_BOOLEAN)(ti4_1 == ti4_2);
		}
		tb1 = '\0';
		if (Result) {
			{
				/* INLINED CODE (is_empty) */
				tb2 = (EIF_BOOLEAN)  0;
				ti4_1 = F1509_14880(Current);
				tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
				/* END INLINED CODE */
			}
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			tb1 = '\0';
			tr1 = F1509_14870(Current);
			loc1 = tr1;
			if (EIF_TEST(loc1)) {
				tr1 = F1509_14870(RTCW(arg1));
				loc2 = tr1;
				tb1 = EIF_TEST(loc2);
			}
			if (tb1) {
				(FUNCTION_CAST(void, (EIF_REFERENCE)) R11799[dtype-1191])(Current);
				(FUNCTION_CAST(void, (EIF_REFERENCE)) R11799[Dtype(arg1)-1191])(RTCW(arg1));
				for (;;) {
					tb1 = '\01';
					{
						/* INLINED CODE (after) */
						tb2 = (EIF_BOOLEAN)  0;
						ti4_1 = F1509_14869(Current);
						ti4_2 = F1509_14880(Current);
						tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_2 + ((EIF_INTEGER_32) 1L)));
						/* END INLINED CODE */
					}
					if (!tb2) {
						tb1 = (EIF_BOOLEAN) !Result;
					}
					if (tb1) break;
					if (*(EIF_BOOLEAN *)(Current + O11691[dtype-1103])) {
						{
							/* INLINED CODE (item) */
							tu1_1 = (EIF_NATURAL_8)  0;
							tr1 = *(EIF_REFERENCE *)(Current);
							ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
							tu1_1 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						tu1_2 = tu1_1;
						{
							/* INLINED CODE (item) */
							tu1_3 = (EIF_NATURAL_8)  0;
							tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
							ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
							tu1_3 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						tu1_3 = tu1_3;
						Result = (EIF_BOOLEAN) (tu1_2 == tu1_3);
					} else {
						{
							/* INLINED CODE (item) */
							tu1_1 = (EIF_NATURAL_8)  0;
							tr1 = *(EIF_REFERENCE *)(Current);
							ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
							tu1_1 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						tu1_2 = tu1_1;
						{
							/* INLINED CODE (item) */
							tu1_3 = (EIF_NATURAL_8)  0;
							tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
							ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
							tu1_3 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						tu1_3 = tu1_3;
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu1_2 == tu1_3);
					}
					{
						/* INLINED CODE (forth) */
						(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))++;
						/* END INLINED CODE */
					}
					;
					{
						/* INLINED CODE (forth) */
						(*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_))++;
						/* END INLINED CODE */
					}
					;
				}
				F1509_14895(Current, loc1);
				F1509_14895(RTCW(arg1), loc2);
			} else {
			}
		} else {
			tb2 = '\0';
			tb3 = '\0';
			{
				/* INLINED CODE (is_empty) */
				tb4 = (EIF_BOOLEAN)  0;
				ti4_1 = F1509_14880(Current);
				tb4 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
				/* END INLINED CODE */
			}
			if (tb4) {
				{
					/* INLINED CODE (is_empty) */
					tb4 = (EIF_BOOLEAN)  0;
					ti4_1 = F1509_14880(RTCW(arg1));
					tb4 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
					/* END INLINED CODE */
				}
				tb4 = tb4;
				tb3 = tb4;
			}
			if (tb3) {
				tb3 = *(EIF_BOOLEAN *)(RTCW(arg1) + O11691[Dtype(arg1)-1103]);
				tb2 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current + O11691[dtype-1103]) == tb3);
			}
			if (tb2) {
				RTLE;
				return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		}
	}
	RTLE;
	return Result;
}

/* {LIST}.after */
EIF_BOOLEAN F1450_14548 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
	{
		/* INLINED CODE (count) */
		ti4_2 = (EIF_INTEGER_32)  0;
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_3 + ((EIF_INTEGER_32) 1L)));
	RTLE;
	return Result;
}

/* {LIST}.before */
EIF_BOOLEAN F1450_14549 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) == ((EIF_INTEGER_32) 0L));
}

void EIF_Minit3288 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
